-- vim: ts=2 sw=2 ai et enc=utf8 fenc=utf8

local RC = RaidChecklist
local RCData = RaidChecklistData
local P = RaidChecklistPetFamilies

if not RC then return end

RC.petproviders = { }
for i,b in ipairs (RCData.buffs) do RC.petproviders[b] = {} end
for i,b in ipairs (RCData.debuffs) do RC.petproviders[b] = {} end
for i,b in ipairs (RCData.dispels) do RC.petproviders[b] = {} end
for i,b in ipairs (RCData.ccs) do RC.petproviders[b] = {} end
for i,b in ipairs (RCData.miscs) do RC.petproviders[b] = {} end

local matrix = {}
for _, pet in pairs (RaidChecklistPetFamilies) do matrix[pet] = {} end
for _, entry in ipairs (RaidChecklistData.table) do
  if entry.p then table.insert (matrix[entry.p], entry.a) end
end

local function remove_petprovider (rguid)
  for key,guidlist in pairs (RC.petproviders) do
    guidlist[rguid] = nil
  end
  if (RC.OnRefresh) then RC:OnRefresh () end
end


local function add_petprovider (buff, guid)
  RC.petproviders[buff][guid] = true
  if (RC.OnRefresh) then RC:OnRefresh () end
end


local RCB = RaidChecklist.button

function RCB:UNIT_PET (unit)
  -- Filter out units we don't care about
  local filtered = string.gsub (unit, "%d", "")
  if filtered ~= "player" and filtered ~= "party" and filtered ~= "raid" then
    return
  end

  local guid = UnitGUID (unit)
  if not guid then return end
  remove_petprovider (guid)
  local family = UnitCreatureFamily (unit.."pet")
  if not family then return end
  local list = matrix[family]
  if not list then
    -- Maybe we haven't got the right family name, or I messed up the locale info...
    DEFAULT_CHAT_FRAME:AddMessage("RaidChecklist: missing family '"..(family or "nil").."', please report this so it can be fixed!")
    return
  end
  for i,key in ipairs (list) do
    add_petprovider (key, guid)
  end
end

RCB:RegisterEvent("UNIT_PET")

